==> weld-servlet-1.1.29-20150205.143058-3-sources.jar: org/jboss/weld/bootstrap/events/AbstractDefinitionContainerEvent.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.bootstrap.events;

import org.jboss.weld.bootstrap.BeanDeployment;
import org.jboss.weld.bootstrap.spi.BeanDeploymentArchive;
import org.jboss.weld.exceptions.DefinitionException;
import org.jboss.weld.manager.BeanManagerImpl;

import java.lang.reflect.Type;
import java.util.Map;

/**
 * @author pmuir
 */
public abstract class AbstractDefinitionContainerEvent extends AbstractContainerEvent {

    protected AbstractDefinitionContainerEvent(BeanManagerImpl beanManager, Type rawType, Type[] actualTypeArguments) {
        super(beanManager, rawType, actualTypeArguments);
    }

    @Override
    protected void fire() {
        super.fire();
        if (!getErrors().isEmpty()) {
            throw new DefinitionException(getErrors());
        }
    }

    @Override
    protected void fire(Map<BeanDeploymentArchive, BeanDeployment> beanDeployments) {
        super.fire(beanDeployments);
        if (!getErrors().isEmpty()) {
            throw new DefinitionException(getErrors());
        }
    }

}

==> weld-servlet-2.0.0-20130404.040747-451-sources.jar: org/jboss/weld/bootstrap/events/AbstractDefinitionContainerEvent.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.bootstrap.events;

import org.jboss.weld.bootstrap.BeanDeployment;
import org.jboss.weld.bootstrap.spi.BeanDeploymentArchive;
import org.jboss.weld.exceptions.DefinitionException;
import org.jboss.weld.manager.BeanManagerImpl;

import java.lang.reflect.Type;
import java.util.Map;

/**
 * @author pmuir
 */
public abstract class AbstractDefinitionContainerEvent extends AbstractContainerEvent {

    protected AbstractDefinitionContainerEvent(BeanManagerImpl beanManager, Type rawType, Type[] actualTypeArguments) {
        super(beanManager, rawType, actualTypeArguments);
    }

    @Override
    public void fire() {
        super.fire();
        if (!getErrors().isEmpty()) {
            throw new DefinitionException(getErrors());
        }
    }
}
